@@ -19,7 +19,7 @@ sub is_hostname;
 ## updated by autoconf
 $PATH_TO_RPCINFO = "/usr/bin/rpcinfo" ;
 $PATH_TO_LMSTAT  = "" ;
-$PATH_TO_SMBCLIENT = "" ;
+$PATH_TO_SMBCLIENT = "/usr/local/bin/smbclient" ;
 $PATH_TO_MAILQ   = "/usr/bin/mailq";
 $PATH_TO_QMAIL_QSTAT = "";
 
@@ -31,7 +31,7 @@ $TIMEOUT = 15;
 sub print_revision ($$) {
 	my $commandName = shift;
 	my $pluginRevision = shift;
-	print "$commandName v$pluginRevision (nagios-plugins 1.4.16)\n";
+	print "$commandName v$pluginRevision (nagios-plugins 1.5)\n";
 	print "The nagios plugins come with ABSOLUTELY NO WARRANTY. You may redistribute\ncopies of the plugins under the terms of the GNU General Public License.\nFor more information about these matters, see the file named COPYING.\n";
 }
 
